@@ -128,7 +128,7 @@ class SynctexViewHelper:
         del self._highlight_tag
 
     def update_location(self):
-        gfile = self._doc.get_location()
+        gfile = self._doc.get_file().get_location()
 
         if gfile is None:
             return
@@ -176,7 +176,7 @@ class SynctexViewHelper:
         self._highlight()
         self._window.present_with_time (time)
 
-    def goto_line_after_load(self, a, line, time):
+    def goto_line_after_load(self, line, time):
         GObject.idle_add (lambda : self.goto_line(line, time))
         self._doc.disconnect(self._goto_handler)
 
@@ -262,7 +262,7 @@ class SynctexWindowActivatable(GObject.Object, Gedit.WindowActivatable):
 
     def add_helper(self, view, window):
         helper = SynctexViewHelper(view, window, self)
-        location = view.get_buffer().get_location()
+        location = view.get_buffer().get_file().get_location()
 
         if location is not None:
             self.view_dict[location.get_uri()] = helper
